>From ab06a9a678ea932668ce30902f829c9a26ab731f Mon Sep 17 00:00:00 2001
From: Craig Ringer <ringerc@ringerc.id.au>
Date: Mon, 5 Nov 2012 11:32:14 +0800
Subject: [PATCH] Correct spelling - occured -> occurred

---
 org/postgresql/Driver.java.in                                |  4 ++--
 org/postgresql/core/ResultHandler.java                       |  2 +-
 org/postgresql/core/v2/ConnectionFactoryImpl.java            |  4 ++--
 org/postgresql/core/v2/QueryExecutorImpl.java                |  8 ++++----
 org/postgresql/core/v3/ConnectionFactoryImpl.java            |  4 ++--
 org/postgresql/core/v3/QueryExecutorImpl.java                | 12 ++++++------
 .../ds/jdbc23/AbstractJdbc23PoolingDataSource.java           |  2 +-
 org/postgresql/jdbc2/AbstractJdbc2Array.java                 |  2 +-
 org/postgresql/test/jdbc2/StatementTest.java                 |  2 +-
 9 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/org/postgresql/Driver.java.in b/org/postgresql/Driver.java.in
index f6c69c0..d7c7821 100644
--- a/org/postgresql/Driver.java.in
+++ b/org/postgresql/Driver.java.in
@@ -284,7 +284,7 @@ public class Driver implements java.sql.Driver
         catch (Exception ex2)
         {
             logger.debug("Unexpected connection error:", ex2);
-            throw new PSQLException(GT.tr("Something unusual has occured to cause the driver to fail. Please report this exception."),
+            throw new PSQLException(GT.tr("Something unusual has occurred to cause the driver to fail. Please report this exception."),
                                     PSQLState.UNEXPECTED_ERROR, ex2);
         }
     }
@@ -348,7 +348,7 @@ public class Driver implements java.sql.Driver
                             resultException.fillInStackTrace();
                             throw (SQLException)resultException;
                         } else {
-                            throw new PSQLException(GT.tr("Something unusual has occured to cause the driver to fail. Please report this exception."),
+                            throw new PSQLException(GT.tr("Something unusual has occurred to cause the driver to fail. Please report this exception."),
                                                     PSQLState.UNEXPECTED_ERROR, resultException);
                         }
                     }
diff --git a/org/postgresql/core/ResultHandler.java b/org/postgresql/core/ResultHandler.java
index f72719f..0ac3797 100644
--- a/org/postgresql/core/ResultHandler.java
+++ b/org/postgresql/core/ResultHandler.java
@@ -57,7 +57,7 @@ public interface ResultHandler {
     /**
      * Called when a warning is emitted.
      *
-     * @param warning the warning that occured.
+     * @param warning the warning that occurred.
      */
     void handleWarning(SQLWarning warning);
 
diff --git a/org/postgresql/core/v2/QueryExecutorImpl.java b/org/postgresql/core/v2/QueryExecutorImpl.java
index bfa83de..f3fc3ee 100644
--- a/org/postgresql/core/v2/QueryExecutorImpl.java
+++ b/org/postgresql/core/v2/QueryExecutorImpl.java
@@ -115,7 +115,7 @@ public class QueryExecutorImpl implements QueryExecutor {
             }
             catch (IOException ioe)
             {
-                throw new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
+                throw new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
             }
         }
 
@@ -126,7 +126,7 @@ public class QueryExecutorImpl implements QueryExecutor {
         }
         catch (IOException ioe)
         {
-            throw new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
+            throw new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
         }
     }
 
@@ -171,7 +171,7 @@ public class QueryExecutorImpl implements QueryExecutor {
                 }
             }
         } catch (IOException ioe) {
-            throw new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
+            throw new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
         }
     }
 
@@ -366,7 +366,7 @@ public class QueryExecutorImpl implements QueryExecutor {
         catch (IOException e)
         {
             protoConnection.close();
-            handler.handleError(new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
+            handler.handleError(new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
         }
 
         handler.handleCompletion();
diff --git a/org/postgresql/core/v3/QueryExecutorImpl.java b/org/postgresql/core/v3/QueryExecutorImpl.java
index 54dd104..edc50bb 100644
--- a/org/postgresql/core/v3/QueryExecutorImpl.java
+++ b/org/postgresql/core/v3/QueryExecutorImpl.java
@@ -278,7 +278,7 @@ public class QueryExecutorImpl implements QueryExecutor {
         catch (IOException e)
         {
             protoConnection.close();
-            handler.handleError(new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
+            handler.handleError(new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
         }
 
         handler.handleCompletion();
@@ -408,7 +408,7 @@ public class QueryExecutorImpl implements QueryExecutor {
         catch (IOException e)
         {
             protoConnection.close();
-            handler.handleError(new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
+            handler.handleError(new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
         }
 
         handler.handleCompletion();
@@ -482,7 +482,7 @@ public class QueryExecutorImpl implements QueryExecutor {
         catch (IOException ioe)
         {
             protoConnection.close();
-            throw new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
+            throw new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
         }
     }
 
@@ -548,7 +548,7 @@ public class QueryExecutorImpl implements QueryExecutor {
             }
             catch (IOException ioe)
             {
-                throw new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
+                throw new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
             }
         }
 
@@ -628,7 +628,7 @@ public class QueryExecutorImpl implements QueryExecutor {
                 }
             }
         } catch (IOException ioe) {
-            throw new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
+            throw new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, ioe);
         }
     }
     
@@ -2091,7 +2091,7 @@ public class QueryExecutorImpl implements QueryExecutor {
         catch (IOException e)
         {
             protoConnection.close();
-            handler.handleError(new PSQLException(GT.tr("An I/O error occured while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
+            handler.handleError(new PSQLException(GT.tr("An I/O error occurred while sending to the backend."), PSQLState.CONNECTION_FAILURE, e));
         }
 
         handler.handleCompletion();
diff --git a/org/postgresql/ds/jdbc23/AbstractJdbc23PoolingDataSource.java b/org/postgresql/ds/jdbc23/AbstractJdbc23PoolingDataSource.java
index 6546765..28f0329 100644
--- a/org/postgresql/ds/jdbc23/AbstractJdbc23PoolingDataSource.java
+++ b/org/postgresql/ds/jdbc23/AbstractJdbc23PoolingDataSource.java
@@ -470,7 +470,7 @@ public abstract class AbstractJdbc23PoolingDataSource extends BaseDataSource
                         }
                         else
                         {
-                            // a connection error occured
+                            // a connection error occurred
                         }
                     }
                 }
diff --git a/org/postgresql/jdbc2/AbstractJdbc2Array.java b/org/postgresql/jdbc2/AbstractJdbc2Array.java
index 23bc4f7..dd5b9a1 100644
--- a/org/postgresql/jdbc2/AbstractJdbc2Array.java
+++ b/org/postgresql/jdbc2/AbstractJdbc2Array.java
@@ -378,7 +378,7 @@ public abstract class AbstractJdbc2Array
             StringBuffer buffer = null;
             boolean insideString = false;
             boolean wasInsideString = false; // needed for checking if NULL
-            // value occured
+            // value occurred
             List dims = new ArrayList(); // array dimension arrays
             PgArrayList curArray = arrayList; // currently processed array
 
diff --git a/org/postgresql/test/jdbc2/StatementTest.java b/org/postgresql/test/jdbc2/StatementTest.java
index 0fb9373..2688666 100644
--- a/org/postgresql/test/jdbc2/StatementTest.java
+++ b/org/postgresql/test/jdbc2/StatementTest.java
@@ -487,7 +487,7 @@ public class StatementTest extends TestCase
     		timer.schedule( new TimerTask(){
     			public void run() 
     			{
-    				fail("Query timeout should have occured and cleaned this up");
+    				fail("Query timeout should have occurred and cleaned this up");
     			}
     		}, 5000);
     		stmt.setQueryTimeout(1);
diff --git a/org/postgresql/core/v2/ConnectionFactoryImpl.java b/org/postgresql/core/v2/ConnectionFactoryImpl.java
index a0cfc96..183a299 100644
--- a/org/postgresql/core/v2/ConnectionFactoryImpl.java
+++ b/org/postgresql/core/v2/ConnectionFactoryImpl.java
@@ -220,7 +220,7 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
             return pgStream;
 
         default:
-            throw new PSQLException(GT.tr("An error occured while setting up the SSL connection."), PSQLState.PROTOCOL_VIOLATION);
+            throw new PSQLException(GT.tr("An error occurred while setting up the SSL connection."), PSQLState.PROTOCOL_VIOLATION);
         }
     }
 
@@ -260,7 +260,7 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
             switch (beresp)
             {
             case 'E':
                 // An error occured, so pass the error message to the
                 // user.
                 //
                 // The most common one to be thrown here is:
@@ -260,7 +260,7 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
             {
             case 'E':
-                // An error occured, so pass the error message to the
+                // An error occurred, so pass the error message to the
                 // user.
                 //
diff --git a/org/postgresql/core/v3/ConnectionFactoryImpl.java b/org/postgresql/core/v3/ConnectionFactoryImpl.java
index 95eaa43..0c54df8 100644
--- a/org/postgresql/core/v3/ConnectionFactoryImpl.java
+++ b/org/postgresql/core/v3/ConnectionFactoryImpl.java
@@ -317,7 +317,7 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
             return pgStream;
 
         default:
-            throw new PSQLException(GT.tr("An error occured while setting up the SSL connection."), PSQLState.PROTOCOL_VIOLATION);
+            throw new PSQLException(GT.tr("An error occurred while setting up the SSL connection."), PSQLState.PROTOCOL_VIOLATION);
         }
     }
 
@@ -378,7 +378,7 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
             switch (beresp)
             {
             case 'E':
                 // An error occured, so pass the error message to the
                 // user.
                 //
                 // The most common one to be thrown here is:
@@ -378,7 +378,7 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
             {
             case 'E':
-                // An error occured, so pass the error message to the
+                // An error occurred, so pass the error message to the
                 // user.
                 //
-- 
1.7.11.7

